ihaskell-0.13.0.0: A Haskell backend kernel for the Jupyter project.
Safe HaskellNone
LanguageHaskell2010

IHaskell.Eval.ParseShell

Description

This module splits a shell command line into a list of strings, one for each command / filename

Documentation