| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
IHaskell.Eval.ParseShell
Description
This module splits a shell command line into a list of strings, one for each command / filename
Documentation
parseShell :: String -> Either ParseError [String] Source #
| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
IHaskell.Eval.ParseShell
Description
This module splits a shell command line into a list of strings, one for each command / filename
parseShell :: String -> Either ParseError [String] Source #